@@ -145,7 +145,7 @@ stop_subscript <- function(i,
     class = c(class, "vctrs_error_subscript"),
     i = i,
     ...,
-    call = vctrs_error_call(call)
+    call = call
   )
 }
 new_error_subscript <- function(class = NULL, i, ...) {
@@ -169,12 +169,12 @@ new_error_subscript_type <- function(i,
     numeric = numeric,
     character = character,
     ...,
-    call = vctrs_error_call(call)
+    call = call
   )
 }
 
 #' @export
-cnd_header.vctrs_error_subscript_type <- function(cnd) {
+cnd_header.vctrs_error_subscript_type <- function(cnd, ...) {
   arg <- cnd[["subscript_arg"]]
   if (is_subscript_arg(arg)) {
     with <- glue::glue(" with {format_subscript_arg(arg)}")
@@ -192,7 +192,7 @@ cnd_header.vctrs_error_subscript_type <- function(cnd) {
   }
 }
 #' @export
-cnd_body.vctrs_error_subscript_type <- function(cnd) {
+cnd_body.vctrs_error_subscript_type <- function(cnd, ...) {
   arg <- cnd_subscript_arg(cnd)
   type <- obj_type_friendly(cnd$i)
   expected_types <- cnd_subscript_expected_types(cnd)
