@@ -6,6 +6,8 @@ knitr::opts_chunk$set(
 
 ## ----setup--------------------------------------------------------------------
 library(vctrs)
+library(rlang)
+library(zeallot)
 
 ## -----------------------------------------------------------------------------
 vec_ptype_show(median(c(1L, 1L)))
@@ -43,11 +45,16 @@ c(FALSE, list(1))
 vec_c(FALSE, list(1))
 
 ## -----------------------------------------------------------------------------
-c(Sys.Date(), factor("x"), "x")
+c(10.5, factor("x"))
 
 ## -----------------------------------------------------------------------------
 c(mean, globalenv())
 
+## ---- error = TRUE------------------------------------------------------------
+c(getRversion(), "x")
+
+c("x", getRversion())
+
 ## ---- error = TRUE------------------------------------------------------------
 vec_c(mean, globalenv())
 
@@ -142,7 +149,10 @@ vec_c(m, 1)
 
 ## -----------------------------------------------------------------------------
 if_else <- function(test, yes, no) {
-  vec_assert(test, logical())
+  if (!is_logical(test)) {
+    abort("`test` must be a logical vector.")
+  }
+  
   c(yes, no) %<-% vec_cast_common(yes, no)
   c(test, yes, no) %<-% vec_recycle_common(test, yes, no)
 
